@@ -131,7 +131,17 @@ get_layout.tidy_results <- function(x, ..., layout_algorithm = "layout_as_tree")
   cl[[1L]] <- str2lang("tidySEM:::get_edges.tidy_results")
   cl <- cl[c(1L, which(names(cl) == "x"))]
   df <- eval.parent(cl)[c("from", "to")]
-  g <- graph.data.frame(df, directed = TRUE)
+  get_layout(df)
+}
+
+#' @method get_layout tidy_edges
+#' @export
+#' @importFrom igraph graph.data.frame vertex.attributes
+#' layout_as_star layout_as_tree layout_in_circle layout_nicely
+#' layout_on_grid layout_randomly layout_with_dh layout_with_fr layout_with_gem
+#' layout_with_graphopt layout_with_kk layout_with_lgl layout_with_mds
+get_layout.tidy_edges <- function(x, ..., layout_algorithm = "layout_as_tree"){
+  g <- graph.data.frame(x, directed = TRUE)
   lo <- do.call(layout_algorithm, list(g))
   lo <- round(lo)
   if(any(duplicated(lo))){
